<?php
/**
 * Elementor Compatibility File.
 *
 * @package Shoptimizer
 */

namespace Elementor;

// If plugin - 'Elementor' not exist then return.
if ( ! class_exists( '\Elementor\Plugin' ) || ! class_exists( 'ElementorPro\Modules\ThemeBuilder\Module' ) ) {
	return;
}

namespace ElementorPro\Modules\ThemeBuilder\ThemeSupport;

use Elementor\TemplateLibrary\Source_Local;
use ElementorPro\Modules\ThemeBuilder\Classes\Locations_Manager;
use ElementorPro\Modules\ThemeBuilder\Module;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Shoptimizer Elementor Compatibility
 */
if ( ! class_exists( 'Shoptimizer_Elementor_Pro' ) ) :

	/**
	 * Shoptimizer Elementor Compatibility
	 *
	 * @since 1.8.0
	 */
	class Shoptimizer_Elementor_Pro {

		/**
		 * Member Variable
		 *
		 * @var object instance
		 */
		private static $instance;

		/**
		 * Initiator
		 *
		 * @since 1.8.0
		 * @return object Class object.
		 */
		public static function get_instance() {
			if ( ! isset( self::$instance ) ) {
				self::$instance = new self();
			}
			return self::$instance;
		}

		/**
		 * Constructor
		 *
		 * @since 1.8.0
		 */
		public function __construct() {
			// Add locations.
			add_action( 'elementor/theme/register_locations', array( $this, 'register_locations' ) );

			// Override theme templates.

			// Header
			add_action( 'shoptimizer_topbar', array( $this, 'do_header' ), 0 );
			add_action( 'shoptimizer_header', array( $this, 'do_header' ), 0 );

			// Footer
			add_action( 'shoptimizer_before_footer', array( $this, 'do_footer' ), 0 );
			add_action( 'shoptimizer_footer', array( $this, 'do_footer' ), 0 );

		}

		/**
		 * Register Locations
		 *
		 * @since 1.8.0
		 * @param object $manager Location manager.
		 * @return void
		 */
		public function register_locations( $manager ) {
			$manager->register_all_core_location();
		}

		/**
		 * Header Support
		 *
		 * @since 1.8.0
		 * @return void
		 */
		public function do_header() {
			$did_location = Module::instance()->get_locations_manager()->do_location( 'header' );
			if ( $did_location ) {
				remove_action( 'shoptimizer_topbar', 'shoptimizer_top_bar', 10 );
				remove_action( 'shoptimizer_header', 'shoptimizer_site_branding', 20 );
				remove_action( 'shoptimizer_header', 'shoptimizer_product_search', 25 );
				remove_action( 'shoptimizer_header', 'shoptimizer_secondary_navigation', 30 );
				add_action( 'shoptimizer_header', 'shoptimizer_elementor_pro_styling', 40 );
			}
		}

		/**
		 * Footer Support
		 *
		 * @since 1.8.0
		 * @return void
		 */
		public function do_footer() {
			$did_location = Module::instance()->get_locations_manager()->do_location( 'footer' );
			if ( $did_location ) {
				remove_action( 'shoptimizer_before_footer', 'shoptimizer_below_content', 10 );
 				remove_action( 'shoptimizer_footer', 'shoptimizer_footer_widgets', 20 );
				remove_action( 'shoptimizer_footer', 'shoptimizer_footer_copyright', 30 );
			}
		}


		}

	Shoptimizer_Elementor_Pro::get_instance();

endif;
